<!-- markdownlint-disable MD024 -->

# Changelog

Changelog for `lnpy`

## Unreleased

See the fragment files in [changelog.d](https://github.com/usnistgov/tmmc-lnpy)

<!-- scriv-insert-here -->

## v0.4.0 — 2023-05-12

### Added

- Package now available on conda-forge

### Changed

- Changed `examples.load_example_maskddata` to
  `examples.load_example_lnpimasked` for consistency with other method names.

## v0.3.0 — 2023-05-02

### Added

- Added support for python3.11

- Moved `_docstrings` -> `docstrings` to make available
- Moved from local docfiller to module_utilities.docfiller
- Moved from local cached module to module-utilities.cached
- Add support for python3.11

Full set of changes:
[`v0.2.2...0.3.0`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.2.2...0.3.0)

### Changed

- Update package layout
- New linters via pre-commit
- Development env now handled by tox

## v0.2.2 - 2023-04-05

Full set of changes:
[`v0.2.1...v0.2.2`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.2.1...v0.2.2)

## v0.2.1 - 2023-04-04

Full set of changes:
[`v0.2.0...v0.2.1`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.2.0...v0.2.1)

## v0.2.0 - 2023-04-04

Full set of changes:
[`v0.1.5...v0.2.0`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.5...v0.2.0)

## v0.1.5 - 2022-09-28

Full set of changes:
[`v0.1.4...v0.1.5`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.4...v0.1.5)

## v0.1.4 - 2022-09-26

Full set of changes:
[`v0.1.3...v0.1.4`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.3...v0.1.4)

## v0.1.3 - 2022-09-15

Full set of changes:
[`v0.1.2...v0.1.3`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.2...v0.1.3)

## v0.1.2 - 2022-09-14

Full set of changes:
[`v0.1.1...v0.1.2`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.1...v0.1.2)

## v0.1.1 - 2022-09-13

Full set of changes:
[`v0.1.0...v0.1.1`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.1.0...v0.1.1)

## v0.1.0 - 2022-09-13

Full set of changes:
[`v0.0.1...v0.1.0`](https://github.com/usnistgov/tmmc-lnpy/compare/v0.0.1...v0.1.0)

## v0.0.1 - 2022-09-13
